Reference Manual
================

.. toctree::
   :maxdepth: 2

   reference/asymptotics
   reference/backends
   reference/debug
   reference/groebner
   reference/helpers
   reference/kronecker
   reference/settings
   reference/whitney